@@ -100,6 +100,7 @@ from typing import Dict
 from deepsparse import Scheduler, __version__, compile_model
 from deepsparse.benchmark.ort_engine import ORTEngine
 from deepsparse.benchmark.stream_benchmark import model_stream_benchmark
+from deepsparse.cpu import cpu_architecture
 from deepsparse.log import set_logging_level
 from deepsparse.utils import (
     generate_random_inputs,
@@ -150,7 +151,7 @@ def parse_args():
         "-ncores",
         "--num_cores",
         type=int,
-        default=None,
+        default=cpu_architecture().num_available_physical_cores,
         help=(
             "The number of physical cores to run the analysis on, "
             "defaults to all physical cores available on the system"
@@ -332,6 +333,7 @@ def benchmark_model(
 
     orig_model_path = model_path
     model_path = model_to_path(model_path)
+    num_streams = parse_num_streams(num_streams, num_cores, scenario)
 
     # Compile the ONNX into a runnable model
     if engine == DEEPSPARSE_ENGINE:
@@ -343,7 +345,6 @@ def benchmark_model(
             scheduler=scheduler,
             input_shapes=input_shapes,
         )
-        num_streams = parse_num_streams(model.num_streams, model.num_cores, scenario)
     elif engine == ORT_ENGINE:
         model = ORTEngine(
             model=model_path,
@@ -351,7 +352,6 @@ def benchmark_model(
             num_cores=num_cores,
             input_shapes=input_shapes,
         )
-        num_streams = parse_num_streams(num_streams, model.num_cores, scenario)
     else:
         raise ValueError(f"Invalid engine choice '{engine}'")
     _LOGGER.info(model)
