@@ -111,13 +111,13 @@ class QuestionAnsweringPipeline(TransformersPipeline):
     :param alias: optional name to give this pipeline instance, useful when
         inferencing with multiple models. Default is None
     :param sequence_length: sequence length to compile model and tokenizer for.
-        Default is 128
+        If a list of lengths is provided, then for each length, a model and
+        tokenizer will be compiled capable of handling that sequence length
+        (also known as a bucket). Default is 128
     :param doc_stride: if the context is too long to fit with the question for the
         model, it will be split in several chunks with some overlap. This argument
-        controls the size of that overlap. Currently, only reading the first span
-        is supported (everything after doc_stride will be truncated). Default
-        is 128
-    :param max_question_len: maximum length of the question after tokenization.
+        controls the size of that overlap. Default is 128
+    :param max_question_length: maximum length of the question after tokenization.
         It will be truncated if needed. Default is 64
     :param max_answer_length: maximum length of answer after decoding. Default is 15
     :param n_best_size: number of n-best predictions to generate when looking for
@@ -168,8 +168,7 @@ class QuestionAnsweringPipeline(TransformersPipeline):
         """
         :return: if the context is too long to fit with the question for the
             model, it will be split in several chunks with some overlap. This argument
-            controls the size of that overlap. Currently, only reading the first span
-            is supported (everything after doc_stride will be truncated)
+            controls the size of that overlap.
         """
         return self._doc_stride
 
@@ -502,12 +501,17 @@ class QuestionAnsweringPipeline(TransformersPipeline):
         :param pipelines: Different buckets to be used
         :return: The correct Pipeline object (or Bucket) to route input to
         """
-        current_seq_len = len(input_schema.question.split())
+        tokenizer = pipelines[0].tokenizer
+        tokens = tokenizer(
+            " ".join((input_schema.context, input_schema.question)),
+            add_special_tokens=True,
+            return_tensors="np",
+            padding=False,
+            truncation=False,
+        )
 
-        for pipeline in pipelines:
-            if pipeline.sequence_length > current_seq_len:
-                return pipeline
-        return pipelines[-1]
+        input_seq_len = len(tokens)
+        return TransformersPipeline.select_bucket_by_seq_len(input_seq_len, pipelines)
 
     def _tokenize(self, example: SquadExample, *args):
         # The logic here closely matches the tokenization step performed
