@@ -33,7 +33,7 @@
 Pipeline implementation and pydantic models for token classification transformers
 tasks
 """
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Dict, Generator, Iterable, List, Optional, Tuple, Type, Union
 
 import numpy
 from pydantic import BaseModel, Field
@@ -41,6 +41,7 @@ from transformers.file_utils import ExplicitEnum
 from transformers.tokenization_utils_base import PaddingStrategy, TruncationStrategy
 
 from deepsparse import Pipeline
+from deepsparse.pipelines import Joinable, Splittable
 from deepsparse.transformers.pipelines import TransformersPipeline
 
 
@@ -65,7 +66,7 @@ class AggregationStrategy(ExplicitEnum):
     MAX = "max"
 
 
-class TokenClassificationInput(BaseModel):
+class TokenClassificationInput(BaseModel, Splittable):
     """
     Schema for inputs to token_classification pipelines
     """
@@ -85,6 +86,32 @@ class TokenClassificationInput(BaseModel):
         ),
     )
 
+    def split(self) -> Generator["TokenClassificationInput", None, None]:
+        """
+        Split a current `TokenClassificationInput` object with a batch size b, into a
+        generator of b smaller objects with batch size 1, the returned
+        object can be iterated on.
+
+        :return: A Generator of smaller `TokenClassificationInput` objects each
+            representing an input of batch-size 1
+        """
+
+        inputs = self.inputs
+
+        # case 1: do nothing if single input of batch_size 1
+        if isinstance(inputs, str):
+            yield self
+
+        elif isinstance(inputs, list) and len(inputs) and isinstance(inputs[0], str):
+            # case 2: List[str] -> multi-batches of size 1 Or batch-size 1 multi-inputs
+            for input_ in inputs:
+                yield TokenClassificationInput(
+                    inputs=input_, is_split_into_words=self.is_split_into_words
+                )
+
+        else:
+            raise ValueError(f"Could not breakdown {self} into smaller batches")
+
 
 class TokenClassificationResult(BaseModel):
     """
@@ -113,7 +140,7 @@ class TokenClassificationResult(BaseModel):
     )
 
 
-class TokenClassificationOutput(BaseModel):
+class TokenClassificationOutput(BaseModel, Joinable):
     """
     Schema for results of TokenClassificationPipeline inference. Classifications of each
     token stored in a list of lists of batch[sentence[token]]
@@ -127,6 +154,22 @@ class TokenClassificationOutput(BaseModel):
         )
     )
 
+    @staticmethod
+    def join(
+        outputs: Iterable["TokenClassificationOutput"],
+    ) -> "TokenClassificationOutput":
+        """
+        Takes in ab Iterable of `TokenClassificationOutput` objects and combines
+        them into one object representing a bigger batch size
+
+        :return: A new `TokenClassificationOutput` object that represents a bigger batch
+        """
+        predictions = [
+            prediction for output in outputs for prediction in output.predictions
+        ]
+
+        return TokenClassificationOutput(predictions=predictions)
+
 
 @Pipeline.register(
     task="token_classification",
@@ -163,7 +206,9 @@ class TokenClassificationPipeline(TransformersPipeline):
     :param alias: optional name to give this pipeline instance, useful when
         inferencing with multiple models. Default is None
     :param sequence_length: sequence length to compile model and tokenizer for.
-        Default is 128
+        If a list of lengths is provided, then for each length, a model and
+        tokenizer will be compiled capable of handling that sequence length
+        (also known as a bucket). Default is 128
     :param aggregation_strategy: how to aggregate tokens in postprocessing. Options
         include 'none', 'simple', 'first', 'average', and 'max'. Default is None
     :param ignore_labels: list of label names to ignore in output. Default is
@@ -174,7 +219,7 @@ class TokenClassificationPipeline(TransformersPipeline):
         self,
         *,
         aggregation_strategy: AggregationStrategy = AggregationStrategy.NONE,
-        ignore_labels: List[str] = None,
+        ignore_labels: Optional[List[str]] = None,
         **kwargs,
     ):
 
@@ -351,6 +396,26 @@ class TokenClassificationPipeline(TransformersPipeline):
 
         return self.output_schema(predictions=predictions)
 
+    @staticmethod
+    def route_input_to_bucket(
+        *args, input_schema: BaseModel, pipelines: List[TransformersPipeline], **kwargs
+    ) -> Pipeline:
+        """
+        :param input_schema: The schema representing an input to the pipeline
+        :param pipelines: Different buckets to be used
+        :return: The correct Pipeline object (or Bucket) to route input to
+        """
+        tokenizer = pipelines[0].tokenizer
+        tokens = tokenizer(
+            input_schema.inputs,
+            add_special_tokens=True,
+            return_tensors="np",
+            padding=False,
+            truncation=False,
+        )
+        input_seq_len = len(tokens)
+        return TransformersPipeline.select_bucket_by_seq_len(input_seq_len, pipelines)
+
     # utilities below adapted from transformers
 
     def _gather_pre_entities(
